# Django RapidAPI (in progress)

Django Rapid API extension.

*Inspired by [FastAPI](https://fastapi.tiangolo.com/) and [Django Rest Framework](https://www.django-rest-framework.org/).*

![tests](https://github.com/antonrh/django-rapidapi/workflows/tests/badge.svg)
[![codecov](https://codecov.io/gh/antonrh/django-rapidapi/branch/master/graph/badge.svg)](https://codecov.io/gh/antonrh/django-rapidapi)
[![Documentation Status](https://readthedocs.org/projects/django-rapidapi/badge/?version=latest)](https://django-rapidapi.readthedocs.io/en/latest/?badge=latest)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![version](https://img.shields.io/pypi/v/django-rapidapi.svg)](https://pypi.org/project/django-rapidapi/)
[![license](https://img.shields.io/pypi/l/django-rapidapi)](https://github.com/antonrh/django-rapidapi/blob/master/LICENSE)

---

Documentation: https://django-rapidapi.readthedocs.io/

---

## Installing

Install using `pip`:

```bash
pip install django-rapidapi
```

## TODO:

* Documentation
* OpenAPI support (Swagger, ReDoc)
* Pydantic support
* Async views support (with Django 3.1)
* etc.
